/*
  This source is part of the Illumination library
  Copyright (C) 2007  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/Placeholder.h>

namespace Lum {

  Placeholder::Placeholder()
  {
    SetBackground(OS::display->GetFill(OS::Display::plateBackgroundFillIndex));
  }

  void Placeholder::CalcSize()
  {
    minWidth=OS::display->GetSpaceHorizontal(OS::Display::spaceObjectDetail);
    minHeight=OS::display->GetSpaceVertical(OS::Display::spaceObjectDetail);

    width=minWidth;
    height=minHeight;

    Object::CalcSize();
  }

  Placeholder* Placeholder::Create(bool horizontalFlex, bool verticalFlex)
  {
    Placeholder *o;

    o=new Placeholder();
    o->SetFlex(horizontalFlex,verticalFlex);

    return o;
  }
}
